MdWriterOptionsBuilder

Struct MdWriterOptionsBuilder 

pub struct MdWriterOptionsBuilder { /* private fields */ }
Builder for MdWriterOptions.

Implementations

Source

impl MdWriterOptionsBuilder

Where to put link references (for non-inline links).

pub fn footnote_reference_placement( &mut self, value: ReferencePlacement, ) -> &mut Self

Where to put footnote references.

pub fn inline_options(&mut self, value: InlineElemOptions) -> &mut Self

Inline Markdown options.

pub fn include_thematic_breaks(&mut self, value: bool) -> &mut Self

Whether to include thematic breaks between top-level elements.

If true, each top-level element will be separated by a thematic break:

   -----

Note that “top-level” refers to the nodes you pass into MdWriter::write, not to what might otherwise look “top level” to a user. For example, if you were to construct an MdElem::Section with depth 2, and within its body another Section with depth 1, only the outer depth-2 Section would count as top-level for these breaks.

pub fn text_width(&mut self, value: Option<usize>) -> &mut Self

Optional text wrapping.

Code blocks will never wrap, and certain inline elements (like URLs) will be treated as atomic: if any part of them wraps, the whole thing will wrap, and if it starts a line then it will never wrap.

For example:

┌────────────────────────────────┐
│This is a long line that will   │
│wrap. But                       │
│[this](https://example.com/will/not/wrap)
|because it's a URL.             │
└────────────────────────────────┘
pub fn build(&self) -> Result<MdWriterOptions, MdWriterOptionsBuilderError>

Builds a new MdWriterOptions.

Errors

If a required field has not been initialized.